@@ -1,7 +1,7 @@
 test_that("tiger_block_groups_sf() namespaces", {
   expect_true(requireNamespace("data.table", quietly = TRUE))
   expect_true(requireNamespace("jsonlite", quietly = TRUE))
-  expect_true(requireNamespace("httr", quietly = TRUE))
+  expect_true(requireNamespace("downloader", quietly = TRUE))
   expect_true(requireNamespace("sf", quietly = TRUE))
   expect_true(requireNamespace("usmap", quietly = TRUE))
   expect_true(requireNamespace("RplotterPkg", quietly = TRUE))
@@ -19,7 +19,8 @@ test_that("tiger_block_groups_sf()", {
     dc_block_groups_sf <- RcensusPkg::tiger_block_groups_sf(
       state = dc_fips,
       output_dir = output_dir,
-      delete_files = FALSE
+      do_progress = FALSE,
+      delete_files = TRUE
     )
   })
 
