@@ -1,7 +1,7 @@
 test_that("tiger_counties_sf() namespaces", {
   expect_true(requireNamespace("data.table", quietly = TRUE))
   expect_true(requireNamespace("jsonlite", quietly = TRUE))
-  expect_true(requireNamespace("httr", quietly = TRUE))
+  expect_true(requireNamespace("downloader", quietly = TRUE))
   expect_true(requireNamespace("sf", quietly = TRUE))
   expect_true(requireNamespace("usmap", quietly = TRUE))
   expect_true(requireNamespace("RplotterPkg", quietly = TRUE))
@@ -25,9 +25,10 @@ test_that("tiger_counties_sf() Ohio", {
     }
     ohio_counties_sf <- RcensusPkg::tiger_counties_sf(
       output_dir = output_dir,
-      delete_files = FALSE,
       general = TRUE,
-      express = express
+      express = express,
+      do_progress = FALSE,
+      delete_files = TRUE
     )
     a_plot <- RplotterPkg::create_sf_plot(sf = ohio_counties_sf)
   })
