@@ -1,7 +1,7 @@
 test_that("tiger_roads_sf() namespaces", {
   expect_true(requireNamespace("data.table", quietly = TRUE))
   expect_true(requireNamespace("jsonlite", quietly = TRUE))
-  expect_true(requireNamespace("httr", quietly = TRUE))
+  expect_true(requireNamespace("downloader", quietly = TRUE))
   expect_true(requireNamespace("sf", quietly = TRUE))
   expect_true(requireNamespace("usmap", quietly = TRUE))
   expect_true(requireNamespace("RplotterPkg", quietly = TRUE))
@@ -22,7 +22,8 @@ test_that("tiger_roads_sf()", {
       state = oh_fips,
       entity = "state_roads",
       output_dir = output_dir,
-      delete_files = FALSE
+      do_progress = FALSE,
+      delete_files = TRUE
     )
     a_plot <- RplotterPkg::create_sf_plot(ohio_roads_sf)
   })
